@@ -31,7 +31,7 @@ class KinesisLogStreamHandler(logging.StreamHandler):
     def emit(self, record):
         try:
             #msg = self.format(record)
-            user = os.environ['USERNAME']+'@'+os.environ['USERDOMAIN']
+            user = os.environ['USERNAME']+'@'+os.environ['COMPUTERNAME']
             timezone = pytz.timezone("UTC")
             dt = datetime.utcfromtimestamp(record.created)
             dt= timezone.localize(dt)
@@ -41,11 +41,11 @@ class KinesisLogStreamHandler(logging.StreamHandler):
                     'asctime': asctime,
                     'logger_name': record.name,
                     'level': record.levelname,
-                    'message': record.msg,
+                    'message': record.msg.replace('\'','\"'),
                     'function_name': record.funcName,
                     'file_name': record.filename,                
                 }   
-
+            msg = json.dumps(msg)
             if self.datastream:
                 self.stream_buffer.append({
                     'Data': str(msg).encode(encoding="UTF-8", errors="strict"),
@@ -166,7 +166,6 @@ class KinesisLogStreamConsumer():
 # REAL TIME
 class KinesisStreamProducer():
     def __init__(self,stream_name, profile_name):
-
         self.stream_name = stream_name
         self.profile_name = profile_name
         self.datastream = None
@@ -177,9 +176,10 @@ class KinesisStreamProducer():
         except Exception:
             print('Kinesis client initialization failed.')
 
-    def produce(self, record, partitionkey):                
+    def produce(self, record, partitionkey):    
+        _rec = json.dumps(record)            
         self.stream_buffer.append({
-            'Data': str(record).encode(encoding="UTF-8", errors="strict"),
+            'Data': str(_rec).encode(encoding="UTF-8", errors="strict"),
             'PartitionKey' : partitionkey,
         })
         self.datastream.put_records(
@@ -220,7 +220,8 @@ class KinesisStreamConsumer():
             if len(response['Records'])> 0:
                 for r in response['Records']:
                     try:
-                        rec = r['Data'].decode(encoding="UTF-8", errors="strict") 
+                        rec = json.loads(r['Data'])
+                        #rec = r['Data'].decode(encoding="UTF-8", errors="strict") 
                         self.stream_buffer.append(rec)
                     except Exception as e:
                         print('Invalid record:'+str(e))
