@@ -14,6 +14,7 @@ from datetime import datetime, timedelta
 
 from SharedData.Logger import Logger
 from SharedData.SharedDataAWSS3 import S3SyncDownloadTimeSeries,S3Upload
+import SharedData.SharedDataRealTime as SharedDataRealTime
 
 class SharedDataTimeSeries:
 
@@ -336,4 +337,12 @@ class SharedDataTimeSeries:
 
         Logger.log.debug('Writing %s from %s ...%.2f%% %.2f sec!' % \
             (shm_name,startdatestr,100*cy/ny,time.time()-tini))        
-        
\ No newline at end of file
+        
+    
+    def Broadcast(self,idx,col):
+        SharedDataRealTime.Broadcast(
+            self.sharedData,
+            self.feeder,
+            self.period,
+            self.tag,
+            idx,col)
\ No newline at end of file
